@@ -3,7 +3,7 @@ from datetime import datetime
 import json
 import os
 from abc import ABCMeta, abstractmethod
-from distutils.version import StrictVersion
+from packaging.version import parse
 from typing import List, Optional
 
 import click
@@ -182,5 +182,5 @@ class SemversionerFileSystemStorage(SemversionerStorage):
 
     def _list_release_numbers(self) -> List[str]:
         files = [f for f in os.listdir(self.semversioner_path) if os.path.isfile(os.path.join(self.semversioner_path, f))]
-        releases = sorted(list(map(lambda x: x[:-len('.json')], files)), key=StrictVersion, reverse=True)
+        releases = sorted(list(map(lambda x: x[:-len('.json')], files)), key=lambda x: parse(x), reverse=True)
         return releases
